Structs
- Asset
Tree Processor - AssetTreeProcessor is a processor for components that implement the
AssetTreetrait. It allows deserializing and serializing assets, as well as processing them with dependencies based on what theirasset_dependenciesmethod reports. - NoDeps
- A wrapper type for components that do not have any asset dependencies.
Traits
- Asset
Tree - Defines a trait for components that can have asset dependencies.