#[repr(transparent)]pub struct NoDeps<T: Component>(pub T);Expand description
A wrapper type for components that do not have any asset dependencies.
This type is useful when you want to use a component as an asset tree
but it does not implement AssetTree trait or should not give any dependencies.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Component> AssetTree for NoDeps<T>
impl<T: Component> AssetTree for NoDeps<T>
Sourcefn asset_dependencies(&self) -> impl IntoIterator<Item = AssetPathStatic>
fn asset_dependencies(&self) -> impl IntoIterator<Item = AssetPathStatic>
Returns an iterator over the asset dependencies of this component. Read more
Sourceimpl<T: Ord + Component> Ord for NoDeps<T>
impl<T: Ord + Component> Ord for NoDeps<T>
Sourceimpl<T: PartialOrd + Component> PartialOrd for NoDeps<T>
impl<T: PartialOrd + Component> PartialOrd for NoDeps<T>
impl<T: Copy + Component> Copy for NoDeps<T>
impl<T: Eq + Component> Eq for NoDeps<T>
impl<T: Component> StructuralPartialEq for NoDeps<T>